@@ -15,14 +15,26 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 
-__version__ = '1.20130808'
+'''Framework for Unix command line programs
+
+cliapp makes it easier to write typical Unix command line programs, by
+taking care of the common tasks they need to do, such as parsing the
+command line, reading configuration files, setting up logging,
+iterating over lines of input files, and so on.
+
+Homepage: http://liw.fi/cliapp/
+
+'''
+
+
+__version__ = '1.20140719'
 
 
 from fmt import TextFormat
-from settings import (Settings, log_group_name, config_group_name,
-                      perf_group_name)
-from runcmd import runcmd, runcmd_unchecked, shell_quote, ssh_runcmd
 from app import Application, AppException
+from settings import (Settings, log_group_name, config_group_name,
+                      perf_group_name, UnknownConfigVariable)
+from runcmd import runcmd, runcmd_unchecked, shell_quote, ssh_runcmd
 
 # The plugin system
 from hook import Hook, FilterHook
