@@ -190,6 +190,9 @@ class Application(object):
             self.process_args(args)
             self.cleanup()
             self.disable_plugins()
+        except cliapp.UnknownConfigVariable, e: # pragma: no cover
+            stderr.write('ERROR: %s\n' % str(e))
+            sys.exit(1)
         except AppException, e:
             log(traceback.format_exc())
             stderr.write('ERROR: %s\n' % str(e))
@@ -267,20 +270,41 @@ class Application(object):
         if 'help-all' not in self.subcommands:
             self.add_subcommand('help-all', self.help_all)
 
+    def get_subcommand_help_formatter(self, *a, **kw): # pragma: no cover
+        '''Return class to format subcommand documentation.
+
+        The class will be used to format the full docstring of a
+        subcommand description, but not other help texts.
+
+        The class must have a compatible interface with
+        cliapp.TextFormat.
+
+        This method exists for those applications who want to change
+        how help texts are formatted, e.g., to allow Markdown or
+        reStructuredText.
+
+        '''
+
+        return cliapp.TextFormat(*a, **kw)
+
     def _help_helper(self, args, show_all): # pragma: no cover
         try:
             width = int(os.environ.get('COLUMNS', '78'))
         except ValueError:
             width = 78
 
-        fmt = cliapp.TextFormat(width=width)
 
         if args:
-            usage = self._format_usage_for(args[0])
-            description = fmt.format(self._format_subcommand_help(args[0]))
+            cmd = args[0]
+            if cmd not in self.subcommands:
+                raise cliapp.AppException('Unknown subcommand %s' % cmd)
+            usage = self._format_usage_for(cmd)
+            fmt = self.get_subcommand_help_formatter(width=width)
+            description = fmt.format(self._format_subcommand_help(cmd))
             text = '%s\n\n%s' % (usage, description)
         else:
             usage = self._format_usage(all=show_all)
+            fmt = cliapp.TextFormat(width=width)
             description = fmt.format(self._format_description(all=show_all))
             text = '%s\n\n%s' % (usage, description)
 
@@ -350,8 +374,6 @@ class Application(object):
         return '* %%prog %s: %s\n' % (cmd, summary)
 
     def _format_subcommand_help(self, cmd): # pragma: no cover
-        if cmd not in self.subcommands:
-            raise cliapp.AppException('Unknown subcommand %s' % cmd)
         method = self.subcommands[cmd]
         doc = method.__doc__ or ''
         t = doc.split('\n', 1)
@@ -378,16 +400,7 @@ class Application(object):
         if self.settings['log'] == 'syslog':
             handler = self.setup_logging_handler_for_syslog()
         elif self.settings['log'] and self.settings['log'] != 'none':
-            handler = LogHandler(
-                            self.settings['log'],
-                            perms=int(self.settings['log-mode'], 8),
-                            maxBytes=self.settings['log-max'],
-                            backupCount=self.settings['log-keep'],
-                            delay=False)
-            fmt = '%(asctime)s %(levelname)s %(message)s'
-            datefmt = '%Y-%m-%d %H:%M:%S'
-            formatter = logging.Formatter(fmt, datefmt)
-            handler.setFormatter(formatter)
+            handler = self.setup_logging_handler_for_file()
         else:
             handler = self.setup_logging_handler_to_none()
             # reduce amount of pointless I/O
@@ -401,35 +414,43 @@ class Application(object):
         '''Setup a logging.Handler for logging to syslog.'''
 
         handler = logging.handlers.SysLogHandler(address='/dev/log')
-        progname = '%%'.join(self.settings.progname.split('%'))
-        fmt = progname + ": %(levelname)s %(message)s"
-        formatter = logging.Formatter(fmt)
+        formatter = self.setup_logging_formatter_for_syslog()
         handler.setFormatter(formatter)
 
         return handler
 
+    def setup_logging_formatter_for_syslog(self): # pragma: no cover
+        '''Setup a logging.Formatter for syslog.'''
+        progname = '%%'.join(self.settings.progname.split('%'))
+        fmt = progname + ": %(levelname)s %(message)s"
+        return logging.Formatter(fmt)
+
+    def setup_logging_handler_for_file(self): # pragma: no cover
+        '''Setup a logging handler for logging to a named file.'''
+
+        handler = LogHandler(
+            self.settings['log'],
+            perms=int(self.settings['log-mode'], 8),
+            maxBytes=self.settings['log-max'],
+            backupCount=self.settings['log-keep'],
+            delay=False)
+        formatter = self.setup_logging_formatter_for_file()
+        handler.setFormatter(formatter)
+        return handler
+
+    def setup_logging_formatter_for_file(self): # pragma: no cover
+        '''Setup a logging.Formatter for logging to a file.'''
+        fmt = '%(asctime)s %(levelname)s %(message)s'
+        datefmt = '%Y-%m-%d %H:%M:%S'
+        formatter = logging.Formatter(fmt, datefmt)
+        return formatter
+
     def setup_logging_handler_to_none(self): # pragma: no cover
         '''Setup a logging.Handler that does not log anything anywhere.'''
 
         handler = logging.FileHandler('/dev/null')
         return handler
 
-    def setup_logging_handler_to_file(self): # pragma: no cover
-        '''Setup a logging.Handler for logging to a named file.'''
-
-        handler = LogHandler(
-                        self.settings['log'],
-                        perms=int(self.settings['log-mode'], 8),
-                        maxBytes=self.settings['log-max'],
-                        backupCount=self.settings['log-keep'],
-                        delay=False)
-        fmt = self.setup_logging_format()
-        datefmt = self.setup_logging_timestamp()
-        formatter = logging.Formatter(fmt, datefmt)
-        handler.setFormatter(formatter)
-
-        return handler
-
     def setup_logging_format(self): # pragma: no cover
         '''Return format string for log messages.'''
         return '%(asctime)s %(levelname)s %(message)s'
@@ -442,6 +463,13 @@ class Application(object):
         logging.info('%s version %s starts' %
                      (self.settings.progname, self.settings.version))
         logging.debug('sys.argv: %s' % sys.argv)
+
+        logging.debug('current working directory: %s' % os.getcwd())
+        logging.debug('uid: %d' % os.getuid())
+        logging.debug('effective uid: %d' % os.geteuid())
+        logging.debug('gid: %d' % os.getgid())
+        logging.debug('effective gid: %d' % os.getegid())
+
         logging.debug('environment variables:')
         for name in os.environ:
             logging.debug('environment: %s=%s' % (name, os.environ[name]))
@@ -609,7 +637,12 @@ class Application(object):
 
     def _vmrss(self): # pragma: no cover
         '''Return current resident memory use, in KiB.'''
-        f = open('/proc/self/status')
+        if platform.system() != 'Linux':
+            return 0
+        try:
+            f = open('/proc/self/status')
+        except IOError:
+            return 0
         rss = 0
         for line in f:
             if line.startswith('VmRSS'):
