@@ -1,4 +1,4 @@
-# Copyright (C) 2009-2012  Lars Wirzenius
+# Copyright (C) 2009-2013  Lars Wirzenius
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -36,6 +36,16 @@ default_group_names = [
 ]
 
 
+class UnknownConfigVariable(cliapp.AppException):
+
+    def __init__(self, filename, name):
+        self.msg = (
+            '%s: Unknown configuration variable %s' % (filename, name))
+
+    def __str__(self): # pragma: no cover
+        return self.msg
+
+
 class Setting(object):
 
     action = 'store'
@@ -383,16 +393,20 @@ class Settings(object):
         '''Return canonical settings names.'''
         return self._canonical_names[:]
 
-    def require(self, name):
-        '''Raise exception if setting has not been set.
+    def require(self, *setting_names):
+        '''Raise exception if a setting has not been set.
 
         Option must have a value, and a default value is OK.
 
         '''
+        messages = []
 
-        if not self._settingses[name].has_value():
-            raise cliapp.AppException('Setting %s has no value, '
-                                        'but one is required' % name)
+        for name in setting_names:
+            if not self._settingses[name].has_value():
+                messages.append('Setting %s has no value, '
+                                            'but one is required' % name)
+        if len(messages) > 0:
+            raise cliapp.AppException('\n'.join(messages))
 
     def _option_names(self, names):
         '''Turn setting names into option names.
@@ -699,8 +713,10 @@ class Settings(object):
 
     config_files = property(_get_config_files, _set_config_files)
 
-    def set_from_raw_string(self, name, raw_string):
+    def set_from_raw_string(self, pathname, name, raw_string):
         '''Set value of a setting from a raw, unparsed string value.'''
+        if name not in self._settingses:
+           raise UnknownConfigVariable(pathname, name)
         s = self._settingses[name]
         s.parse_value(raw_string)
         return s
@@ -724,11 +740,11 @@ class Settings(object):
                 cp.readfp(f)
                 f.close()
 
-        for name in cp.options('config'):
-            value = cp.get('config', name)
-            s = self.set_from_raw_string(name, value)
-            if hasattr(s, 'using_default_value'):
-                s.using_default_value = True
+                for name in cp.options('config'):
+                    value = cp.get('config', name)
+                    s = self.set_from_raw_string(pathname, name, value)
+                    if hasattr(s, 'using_default_value'):
+                        s.using_default_value = True
 
         # Remember the ConfigParser for use in as_cp later on.
         self._cp = cp
