@@ -336,6 +336,19 @@ bar = ping, pong
         self.assertEqual(self.settings['foo'], 'red')
         self.assertEqual(self.settings['bar'], ['blue', 'white'])
 
+    def test_load_configs_raises_error_for_unknown_variable(self):
+
+        def mock_open(filename, mode=None):
+            return StringIO.StringIO('''\
+[config]
+unknown = variable
+''')
+
+        self.assertRaises(
+            cliapp.UnknownConfigVariable,
+            self.settings.load_configs,
+            open=mock_open)
+
     def test_load_configs_ignore_errors_opening_a_file(self):
 
         def mock_open(filename, mode=None):
@@ -399,6 +412,18 @@ bar = ping, pong
         self.settings.integer(['foo'], 'foo help')
         self.assertEqual(self.settings.require('foo'), None)
 
+    def test_require_raises_error_when_one_value_of_several_is_unset(self):
+        self.settings.string(['foo'], 'foo help')
+        self.settings.string(['bar'], 'bar help', default=None )
+        args = ['foo', 'bar']
+        self.assertRaises(cliapp.AppException, self.settings.require, *args)
+
+    def test_require_is_ok_with_multiple_values(self):
+        self.settings.string(['foo'], 'foo help')
+        self.settings.string(['bar'], 'bar help')
+        args = ['foo', 'bar']
+        self.assertEqual(self.settings.require(*args), None)
+
     def test_exports_configparser_with_settings(self):
         self.settings.integer(['foo'], 'foo help', default=1)
         self.settings.string(['bar'], 'bar help', default='yo')
